@@ -4,7 +4,7 @@ import spotipy
 from spotipy.oauth2 import SpotifyOAuth
 
 from . import scopes as sc, utils
-from .formatting import fprint
+from .formatting import fprint, warning
 
 try:
     scopes = sc.get_scope(sc.SCOPES)
@@ -30,4 +30,5 @@ def get_current_device(default_current = False):
                 if utils.get("current", "this will always be different") != id:
                     utils.add_var("current", id)
                 return None if default_current else id
-    return "No devices currently active"
\ No newline at end of file
+    warning("No devices currently active")
+    return None
\ No newline at end of file
